Heimdallr Documentation
==================

.. automodule:: heimdallr
    :members:

.. toctree::
    :glob:
    :hidden:
    :maxdepth: 1
    :caption: Notes

    getting_started
    readme

What's next?
-------------

Read the :ref:`Getting Started Guide <getting_started>`



Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
